@@ -8,7 +8,7 @@ extends 'API::Basecamp::Client';
 use Carp ();
 use Scalar::Util ();
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 has account => (
     is       => 'rw',
@@ -145,7 +145,7 @@ API::Basecamp - Perl 5 API wrapper for Basecamp
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -154,16 +154,19 @@ version 0.01
     my $basecamp = API::Basecamp->new(
         username   => 'USERNAME',
         password   => 'PASSWORD',
-        identifier => 'APPLICATION (yourname@example.com)',
-        account    => '999999999',
+        identifier => 'APPLICATION NAME',
+        account    => 'ACCOUNT NUMBER',
     );
 
-    my $project = $basecamp->projects(12345);
+    $basecamp->debug(1);
+    $basecamp->fatal(1);
+
+    my $project = $basecamp->projects('605816632');
     my $results = $project->fetch;
 
     # after some introspection
 
-    $project->delete;
+    $project->update( ... );
 
 =head1 DESCRIPTION
 
@@ -173,39 +176,41 @@ documentation information visit L<https://github.com/basecamp/bcx-api>.
 
 =head1 THIN CLIENT
 
-A thin-client library is advantageous as it has complete coverage and can
-easily adapt to changes in the API with minimal effort. As a thin-client
-library, this module does not map specific HTTP requests to specific routines
+A thin-client library is advantageous as it has complete API coverage and
+can easily adapt to changes in the API with minimal effort. As a thin-client
+library, this module does not map specific HTTP requests to specific routines,
 nor does it provide parameter validation, pagination, or other conventions
 found in typical API client implementations, instead, it simply provides a
 simple and consistent mechanism for dynamically generating HTTP requests.
 Additionally, this module has support for debugging and retrying API calls as
 well as throwing exceptions when 4xx and 5xx server response codes are
-received.
+returned.
 
 =head2 Building
 
-    my $project = $basecamp->projects(12345);
-    my $todolists = $project->todolists;
+    my $project = $basecamp->projects('605816632');
 
-    $todolists->action; # GET /projects/12345/todolists
-    $todolists->action('head'); # HEAD /projects/12345/todolists
+    $project->action; # GET /projects/605816632
+    $project->action('head'); # HEAD /projects/605816632
+    $project->action('patch'); # PATCH /projects/605816632
 
 Building up an HTTP request object is extremely easy, simply call method names
 which correspond to the API's path segments in the resource you wish to execute
 a request against. This module uses autoloading and returns a new instance with
 each method call. The following is the equivalent:
 
-    my $project = $basecamp->resource(projects => 12345);
-    my $todolists = $project->resource('todolists');
+=head2 Chaining
+
+    my $project = $basecamp->resource('projects', '605816632');
 
     # or
 
-    my $todolists = $basecamp->resource('projects', 12345, 'todolists');
+    my $projects = $basecamp->projects;
+    my $project  = $projects->resource('605816632');
 
     # then
 
-    $todolists->action('put', %args); # PUT /projects/12345/todolists
+    $project->action('put', %args); # PUT /projects/605816632
 
 Because each call returns a new API instance configured with a resource locator
 based on the supplied parameters, reuse and request isolation are made simple,
@@ -215,17 +220,15 @@ i.e., you will only need to configure the client once in your application.
 
     my $projects = $basecamp->projects;
 
-    $projects->fetch(
-        query => {
-            # query-string parameters
-        },
-    );
+    # query-string parameters
+
+    $projects->fetch( query => { ... } );
 
     # equivalent to
 
-    $basecamp->resource('projects')->action(
-        get => ( query => { ... } )
-    );
+    my $projects = $basecamp->resource('projects');
+
+    $projects->action( get => ( query => { ... } ) );
 
 This example illustrates how you might fetch an API resource.
 
@@ -233,18 +236,13 @@ This example illustrates how you might fetch an API resource.
 
     my $projects = $basecamp->projects;
 
-    $projects->create(
-        data => {
-            # content-body parameters
-        },
-        query => {
-            # query-string parameters
-        },
-    );
+    # content-body parameters
 
-    # or
+    $projects->create( data => { ... } );
 
-    my $projects = $basecamp->projects->create(...);
+    # query-string parameters
+
+    $projects->create( query => { ... } );
 
     # equivalent to
 
@@ -257,20 +255,19 @@ This example illustrates how you might create a new API resource.
 =head2 Updating
 
     my $projects = $basecamp->projects;
-    my $project  = $projects->resource(12345);
+    my $project  = $projects->resource('605816632');
 
-    $project->update(
-        data => {
-            # content-body parameters
-        },
-        query => {
-            # query-string parameters
-        },
-    );
+    # content-body parameters
+
+    $project->update( data => { ... } );
+
+    # query-string parameters
+
+    $project->update( query => { ... } );
 
     # or
 
-    my $project = $basecamp->projects(12345);
+    my $project = $basecamp->projects('605816632');
 
     $project->update(...);
 
@@ -280,25 +277,24 @@ This example illustrates how you might create a new API resource.
         put => ( query => { ... }, data => { ... } )
     );
 
-This example illustrates how you might update an new API resource.
+This example illustrates how you might update a new API resource.
 
 =head2 Deleting
 
     my $projects = $basecamp->projects;
-    my $project  = $projects->resource(12345);
+    my $project  = $projects->resource('605816632');
 
-    $project->delete(
-        data => {
-            # content-body parameters
-        },
-        query => {
-            # query-string parameters
-        },
-    );
+    # content-body parameters
+
+    $project->delete( data => { ... } );
+
+    # query-string parameters
+
+    $project->delete( query => { ... } );
 
     # or
 
-    my $project = $basecamp->projects(12345);
+    my $project = $basecamp->projects('605816632');
 
     $project->delete(...);
 
@@ -312,35 +308,24 @@ This example illustrates how you might delete an API resource.
 
 =head2 Transacting
 
-    my $project = $basecamp->resource('projects', '12345');
+    my $projects = $basecamp->resource('projects', '605816632');
 
-    my ($results, $transaction) = $project->fetch(...);
+    my ($results, $transaction) = $projects->action( ... );
 
-This example illustrates how you can access the transaction object used to
-submit the HTTP request.
+    my $request  = $transaction->req;
+    my $response = $transaction->res;
 
-=head1 PARAMETERS
+    my $headers;
 
-=head2 username
+    $headers = $request->headers;
+    $headers = $response->headers;
 
-    $basecamp->username;
-    $basecamp->username('USERNAME');
+    # etc
 
-The username parameter should be set to the account holder's username.
+This example illustrates how you can access the transaction object used
+represent and process the HTTP transaction.
 
-=head2 password
-
-    $basecamp->password;
-    $basecamp->password('PASSWORD');
-
-The password parameter should be set to the account holder's password.
-
-=head2 identifier
-
-    $basecamp->identifier;
-    $basecamp->identifier('IDENTIFIER');
-
-The identifier parameter should be set using a string to identify your app.
+=head1 ATTRIBUTES
 
 =head2 account
 
@@ -349,7 +334,26 @@ The identifier parameter should be set using a string to identify your app.
 
 The account parameter should be set to the account holder's account ID number.
 
-=head1 ATTRIBUTES
+=head2 identifier
+
+    $basecamp->identifier;
+    $basecamp->identifier('IDENTIFIER');
+
+The identifier parameter should be set to a string that identifies your application.
+
+=head2 password
+
+    $basecamp->password;
+    $basecamp->password('PASSWORD');
+
+The password parameter should be set to the account holder's password.
+
+=head2 username
+
+    $basecamp->username;
+    $basecamp->username('USERNAME');
+
+The username parameter should be set to the account holder's username.
 
 =head2 debug
 
@@ -467,183 +471,156 @@ included in the request if the key is either C<data> or C<query>.
 
 =head2 accesses
 
-    $basecamp->accesses;
+    $basecamp->projects('605816632')->accesses;
 
 The accesses method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/accesses.md>.
+I<Accesses> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/accesses.md>.
 
 =head2 attachments
 
     $basecamp->attachments;
 
 The attachments method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/attachments.md>.
-
-=head2 authentication
-
-    $basecamp->authentication;
-
-The authentication method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/authentication.md>.
+I<Attachments> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/attachments.md>.
 
 =head2 calendar_events
 
     $basecamp->calendar_events;
 
 The calendar_events method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/calendar_events.md>.
+I<Calendar Events> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<>.
 
 =head2 calendars
 
     $basecamp->calendars;
 
 The calendars method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/calendars.md>.
+I<Calendars> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/calendars.md>.
 
 =head2 comments
 
-    $basecamp->comments;
+    $basecamp->projects('605816632')->comments;
 
 The comments method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/comments.md>.
+I<Comments> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/comments.md>.
 
 =head2 documents
 
     $basecamp->documents;
 
 The documents method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/documents.md>.
+I<Documents> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/documents.md>.
 
 =head2 events
 
     $basecamp->events;
 
 The events method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/events.md>.
-
-=head2 forwards
-
-    $basecamp->forwards;
-
-The forwards method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/forwards.md>.
+I<Events> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/events.md>.
 
 =head2 groups
 
     $basecamp->groups;
 
 The groups method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/groups.md>.
+I<Groups> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/groups.md>.
 
 =head2 messages
 
-    $basecamp->messages;
+    $basecamp->projects('605816632')->messages;
 
 The messages method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/messages.md>.
+I<Messages> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/messages.md>.
 
 =head2 people
 
     $basecamp->people;
 
 The people method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/people.md>.
+I<People> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/people.md>.
 
 =head2 project_templates
 
     $basecamp->project_templates;
 
 The project_templates method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/project_templates.md>.
+I<Project Templates> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/project_templates.md>.
 
 =head2 projects
 
     $basecamp->projects;
 
 The projects method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/projects.md>.
+I<Projects> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/projects.md>.
 
 =head2 stars
 
     $basecamp->stars;
 
 The stars method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/stars.md>.
+I<Stars> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/stars.md>.
 
-=head2 tags
+=head2 todo_lists
 
-    $basecamp->tags;
+    $basecamp->todo_lists;
 
-The tags method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/tags.md>.
-
-=head2 todolists
-
-    $basecamp->todolists;
-
-The todolists method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/todolists.md>.
+The todo_lists method returns a new instance representative of the API
+I<Todo Lists> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/todolists.md>.
 
 =head2 todos
 
-    $basecamp->todos;
+    $basecamp->projects('605816632')->todos;
 
 The todos method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/todos.md>.
+I<Todos> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/todos.md>.
 
 =head2 topics
 
     $basecamp->topics;
 
 The topics method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/topics.md>.
+I<Topics> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/topics.md>.
 
 =head2 uploads
 
-    $basecamp->uploads;
+    $basecamp->projects('605816632')->uploads;
 
 The uploads method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://github.com/basecamp/bcx-api/blob/master/sections/uploads.md>.
+I<Uploads> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/uploads.md>.
 
 =head1 AUTHOR
 
